Class: RunApi::Qwen3::Client
- Inherits:
-
Core::Client
- Object
- Core::Client
- RunApi::Qwen3::Client
- Defined in:
- lib/runapi/qwen_3/client.rb
Overview
Qwen 3 image generation and editing API client.
Text-to-image generation and targeted modifications to source images.
Instance Attribute Summary collapse
-
#edit_image ⇒ Resources::EditImage
readonly
Apply targeted edits to a source image using natural-language prompts.
-
#text_to_image ⇒ Resources::TextToImage
readonly
Generate images from text prompts.
Instance Method Summary collapse
-
#initialize(api_key: nil, **options) ⇒ Client
constructor
A new instance of Client.
Constructor Details
Instance Attribute Details
#edit_image ⇒ Resources::EditImage (readonly)
Returns Apply targeted edits to a source image using natural-language prompts.
20 21 22 |
# File 'lib/runapi/qwen_3/client.rb', line 20 def edit_image @edit_image end |
#text_to_image ⇒ Resources::TextToImage (readonly)
Returns Generate images from text prompts.
18 19 20 |
# File 'lib/runapi/qwen_3/client.rb', line 18 def text_to_image @text_to_image end |